pub struct Client {Show 33 fields
pub id: ClientId,
pub channel: ChannelId,
pub uid: Option<UidBuf>,
pub name: String,
pub input_muted: bool,
pub output_muted: bool,
pub output_only_muted: bool,
pub input_hardware_enabled: bool,
pub output_hardware_enabled: bool,
pub talk_power_granted: bool,
pub metadata: String,
pub is_recording: bool,
pub database_id: ClientDbId,
pub channel_group: ChannelGroupId,
pub server_groups: HashSet<ServerGroupId>,
pub away_message: Option<String>,
pub client_type: ClientType,
pub avatar_hash: String,
pub talk_power: i32,
pub talk_power_request: Option<TalkPowerRequest>,
pub description: String,
pub is_priority_speaker: bool,
pub unread_messages: u32,
pub phonetic_name: String,
pub needed_serverquery_view_power: i32,
pub icon: IconId,
pub is_channel_commander: bool,
pub country_code: String,
pub inherited_channel_group_from_channel: ChannelId,
pub badges: String,
pub permission_hints: Option<ClientPermissionHint>,
pub optional_data: Option<OptionalClientData>,
pub connection_data: Option<ConnectionClientData>,
}Expand description
Get in notifycliententerview
Fields
id: ClientIdchannel: ChannelIduid: Option<UidBuf>Unique Identifier
name: Stringinput_muted: booltrue if muted, false otherwise
output_muted: booltrue if muted, false otherwise
output_only_muted: booltrue if muted, false otherwise
input_hardware_enabled: booltrue if enabled, false if disabled
output_hardware_enabled: booltrue if enabled, false if disabled
talk_power_granted: boolIf the client is granted talk power
metadata: StringSet by client
is_recording: boolWhether the client is recording
database_id: ClientDbIdchannel_group: ChannelGroupIdserver_groups: HashSet<ServerGroupId>away_message: Option<String>Contains the away message if the client is away
client_type: ClientTypeIf this client is a server query or not
avatar_hash: StringMD5 hash of the avatar, used to retrieve the avatar
talk_power: i32talk_power_request: Option<TalkPowerRequest>Contains a message and timestamp from the client if he requests talk power
description: Stringis_priority_speaker: boolunread_messages: u32phonetic_name: Stringneeded_serverquery_view_power: i32icon: IconIdis_channel_commander: boolcountry_code: StringLike US, DE
inherited_channel_group_from_channel: ChannelIdbadges: Stringpermission_hints: Option<ClientPermissionHint>optional_data: Option<OptionalClientData>connection_data: Option<ConnectionClientData>Implementations
Sourceimpl Client
impl Client
pub fn connection_info(&self) -> OutClientConnectionInfoRequestPart
Sourceimpl Client
impl Client
pub fn add_server_group(&self, server_group: ServerGroupId) -> OutCommand
Sourceimpl Client
impl Client
pub fn remove_server_group(&self, server_group: ServerGroupId) -> OutCommand
Sourceimpl Client
impl Client
pub fn client_move<'a>(&self, channel: ChannelId) -> OutClientMovePart<'a>
Sourceimpl Client
impl Client
pub fn send_textmessage(&self, message: &str) -> OutCommand
pub fn poke(&self, message: &str) -> OutCommand